==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder5/BibleCS/FontSel.h <==
//---------------------------------------------------------------------------

#ifndef FontSelH
#define FontSelH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <Dialogs.hpp>
#include <ExtCtrls.hpp>
//#include "D:\\Program Files\\Borland\\CBuilder5\\RX\\Units\\Rxcombos.hpp"
#include "RxCombos.hpp"
//---------------------------------------------------------------------------
class TFontSelFrm : public TForm
{
__published:	// IDE-managed Components
	TLabel *Label1;
	TLabel *Label2;
	TLabel *Label3;
	TLabel *Label4;
	TBitBtn *OKBtn;
	TBitBtn *CancelBtn;
	TGroupBox *GroupBox1;
	TPanel *SampleText;
	TFontComboBox *FontComboBox;
	TComboBox *SizeComboBox;
	TCheckBox *ckShowFont;
	TColorComboBox *BGColorCmb;
     TColorComboBox *FGColorCmb;
   	TColorDialog *BackColorDlg;
     TColorDialog *ForeColorDlg;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall ckShowFontClick(TObject *Sender);
	void __fastcall FontComboBoxChange(TObject *Sender);
	void __fastcall SizeComboBoxChange(TObject *Sender);
	void __fastcall BGColorCmbChange(TObject *Sender);
     void __fastcall FGColorCmbChange(TObject *Sender);
	void __fastcall OKBtnClick(TObject *Sender);
	void __fastcall CancelBtnClick(TObject *Sender);
public:	// User declarations
	TFont*		Font;
     int 			BackColor;
public:		// User declarations
	__fastcall TFontSelFrm(TComponent* Owner);
protected:
	void UpdatePreview();
private:
	bool initialized; // Stupid variable to work around stupid combo box change called from FormShow()

};
//---------------------------------------------------------------------------
extern PACKAGE TFontSelFrm *FontSelFrm;
//---------------------------------------------------------------------------
#endif

==> sword-1.5.4.tar.gz: sword-1.5.4/apps/windoze/CBuilder5/BibleCS/FontSel.h <==
//---------------------------------------------------------------------------

#ifndef FontSelH
#define FontSelH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <Dialogs.hpp>
#include <ExtCtrls.hpp>
//#include "D:\\Program Files\\Borland\\CBuilder5\\RX\\Units\\Rxcombos.hpp"
#include "RxCombos.hpp"
//---------------------------------------------------------------------------
class TFontSelFrm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TLabel *Label1;
	TLabel *Label2;
	TLabel *Label3;
	TLabel *Label4;
	TComboBox *SizeComboBox;
	TCheckBox *ckShowFont;
	TPanel *pnlFontComboBox;
	TPanel *pnlBGColorCmb;
	TPanel *pnlFGColorCmb;
	TBitBtn *OKBtn;
	TBitBtn *CancelBtn;
	TGroupBox *GroupBox1;
	TPanel *SampleText;
	TColorDialog *FGColorDlg;
	TColorDialog *BGColorDlg;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall ckShowFontClick(TObject *Sender);
	void __fastcall FontComboBoxChange(TObject *Sender);
	void __fastcall SizeComboBoxChange(TObject *Sender);
	void __fastcall BGColorCmbChange(TObject *Sender);
     void __fastcall FGColorCmbChange(TObject *Sender);
	void __fastcall OKBtnClick(TObject *Sender);
	void __fastcall CancelBtnClick(TObject *Sender);
public:	// User declarations
	TFont*		Font;
     int 			BackColor;
public:		// User declarations
	__fastcall TFontSelFrm(TComponent* Owner);
    TFontComboBox *FontComboBox;
    TColorComboBox *BGColorCmb;
	TColorComboBox *FGColorCmb;
protected:
	void UpdatePreview();
private:
	bool initialized; // Stupid variable to work around stupid combo box change called from FormShow()

};
//---------------------------------------------------------------------------
extern PACKAGE TFontSelFrm *FontSelFrm;
//---------------------------------------------------------------------------
#endif
